# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Any, List, Optional
from typing_extensions import Annotated
from skyledge_sdk.models.form_request import FormRequest
from skyledge_sdk.models.form_response import FormResponse
from skyledge_sdk.models.form_response_response import FormResponseResponse
from skyledge_sdk.models.form_responses_response import FormResponsesResponse
from skyledge_sdk.models.forms_response import FormsResponse
from skyledge_sdk.models.update_form_request import UpdateFormRequest
from skyledge_sdk.models.update_form_response_request import UpdateFormResponseRequest

from skyledge_sdk.api_client import ApiClient, RequestSerialized
from skyledge_sdk.api_response import ApiResponse
from skyledge_sdk.rest import RESTResponseType


class FormsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_form(
        self,
        form_request: FormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponse:
        """create_form


        :param form_request: (required)
        :type form_request: FormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_form_serialize(
            form_request=form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_form_with_http_info(
        self,
        form_request: FormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponse]:
        """create_form


        :param form_request: (required)
        :type form_request: FormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_form_serialize(
            form_request=form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_form_without_preload_content(
        self,
        form_request: FormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """create_form


        :param form_request: (required)
        :type form_request: FormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_form_serialize(
            form_request=form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_form_serialize(
        self,
        form_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if form_request is not None:
            _body_params = form_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/forms',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_form_using_form_id(
        self,
        form_id: StrictStr,
        include_form_token: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponse:
        """get_form_using_form_id


        :param form_id: (required)
        :type form_id: str
        :param include_form_token:
        :type include_form_token: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_id_serialize(
            form_id=form_id,
            include_form_token=include_form_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_form_using_form_id_with_http_info(
        self,
        form_id: StrictStr,
        include_form_token: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponse]:
        """get_form_using_form_id


        :param form_id: (required)
        :type form_id: str
        :param include_form_token:
        :type include_form_token: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_id_serialize(
            form_id=form_id,
            include_form_token=include_form_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_form_using_form_id_without_preload_content(
        self,
        form_id: StrictStr,
        include_form_token: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_form_using_form_id


        :param form_id: (required)
        :type form_id: str
        :param include_form_token:
        :type include_form_token: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_id_serialize(
            form_id=form_id,
            include_form_token=include_form_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_form_using_form_id_serialize(
        self,
        form_id,
        include_form_token,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_id is not None:
            _path_params['formId'] = form_id
        # process the query parameters
        if include_form_token is not None:
            
            _query_params.append(('includeFormToken', include_form_token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms/{formId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_form_using_form_id1(
        self,
        form_id: StrictStr,
        form_response_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponseResponse:
        """get_form_using_form_id1


        :param form_id: (required)
        :type form_id: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_id1_serialize(
            form_id=form_id,
            form_response_id=form_response_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponseResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_form_using_form_id1_with_http_info(
        self,
        form_id: StrictStr,
        form_response_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponseResponse]:
        """get_form_using_form_id1


        :param form_id: (required)
        :type form_id: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_id1_serialize(
            form_id=form_id,
            form_response_id=form_response_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponseResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_form_using_form_id1_without_preload_content(
        self,
        form_id: StrictStr,
        form_response_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_form_using_form_id1


        :param form_id: (required)
        :type form_id: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_id1_serialize(
            form_id=form_id,
            form_response_id=form_response_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponseResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_form_using_form_id1_serialize(
        self,
        form_id,
        form_response_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_id is not None:
            _path_params['formId'] = form_id
        if form_response_id is not None:
            _path_params['formResponseId'] = form_response_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms/{formId}/responses/{formResponseId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_form_using_form_identifier(
        self,
        form_identifier: StrictStr,
        include_form_token: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponse:
        """get_form_using_form_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param include_form_token:
        :type include_form_token: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_identifier_serialize(
            form_identifier=form_identifier,
            include_form_token=include_form_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_form_using_form_identifier_with_http_info(
        self,
        form_identifier: StrictStr,
        include_form_token: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponse]:
        """get_form_using_form_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param include_form_token:
        :type include_form_token: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_identifier_serialize(
            form_identifier=form_identifier,
            include_form_token=include_form_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_form_using_form_identifier_without_preload_content(
        self,
        form_identifier: StrictStr,
        include_form_token: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_form_using_form_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param include_form_token:
        :type include_form_token: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_identifier_serialize(
            form_identifier=form_identifier,
            include_form_token=include_form_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_form_using_form_identifier_serialize(
        self,
        form_identifier,
        include_form_token,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_identifier is not None:
            _path_params['formIdentifier'] = form_identifier
        # process the query parameters
        if include_form_token is not None:
            
            _query_params.append(('includeFormToken', include_form_token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms/identifier={formIdentifier}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_form_using_form_identifier1(
        self,
        form_identifier: StrictStr,
        form_response_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponseResponse:
        """get_form_using_form_identifier1


        :param form_identifier: (required)
        :type form_identifier: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_identifier1_serialize(
            form_identifier=form_identifier,
            form_response_id=form_response_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponseResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_form_using_form_identifier1_with_http_info(
        self,
        form_identifier: StrictStr,
        form_response_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponseResponse]:
        """get_form_using_form_identifier1


        :param form_identifier: (required)
        :type form_identifier: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_identifier1_serialize(
            form_identifier=form_identifier,
            form_response_id=form_response_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponseResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_form_using_form_identifier1_without_preload_content(
        self,
        form_identifier: StrictStr,
        form_response_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_form_using_form_identifier1


        :param form_identifier: (required)
        :type form_identifier: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_form_using_form_identifier1_serialize(
            form_identifier=form_identifier,
            form_response_id=form_response_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponseResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_form_using_form_identifier1_serialize(
        self,
        form_identifier,
        form_response_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_identifier is not None:
            _path_params['formIdentifier'] = form_identifier
        if form_response_id is not None:
            _path_params['formResponseId'] = form_response_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms/identifier={formIdentifier}/responses/{formResponseId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_responses_using_form_id(
        self,
        form_id: StrictStr,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Zero-based page index (0..N)")] = None,
        size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The size of the page to be returned")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.")] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponsesResponse:
        """get_responses_using_form_id


        :param form_id: (required)
        :type form_id: str
        :param page: Zero-based page index (0..N)
        :type page: int
        :param size: The size of the page to be returned
        :type size: int
        :param sort: Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.
        :type sort: List[str]
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_responses_using_form_id_serialize(
            form_id=form_id,
            page=page,
            size=size,
            sort=sort,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponsesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_responses_using_form_id_with_http_info(
        self,
        form_id: StrictStr,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Zero-based page index (0..N)")] = None,
        size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The size of the page to be returned")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.")] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponsesResponse]:
        """get_responses_using_form_id


        :param form_id: (required)
        :type form_id: str
        :param page: Zero-based page index (0..N)
        :type page: int
        :param size: The size of the page to be returned
        :type size: int
        :param sort: Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.
        :type sort: List[str]
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_responses_using_form_id_serialize(
            form_id=form_id,
            page=page,
            size=size,
            sort=sort,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponsesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_responses_using_form_id_without_preload_content(
        self,
        form_id: StrictStr,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Zero-based page index (0..N)")] = None,
        size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The size of the page to be returned")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.")] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_responses_using_form_id


        :param form_id: (required)
        :type form_id: str
        :param page: Zero-based page index (0..N)
        :type page: int
        :param size: The size of the page to be returned
        :type size: int
        :param sort: Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.
        :type sort: List[str]
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_responses_using_form_id_serialize(
            form_id=form_id,
            page=page,
            size=size,
            sort=sort,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponsesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_responses_using_form_id_serialize(
        self,
        form_id,
        page,
        size,
        sort,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sort': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_id is not None:
            _path_params['formId'] = form_id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms/{formId}/responses',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_responses_using_form_identifier(
        self,
        form_identifier: StrictStr,
        search: Optional[StrictStr] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Zero-based page index (0..N)")] = None,
        size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The size of the page to be returned")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormResponsesResponse:
        """get_responses_using_form_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param search:
        :type search: str
        :param page: Zero-based page index (0..N)
        :type page: int
        :param size: The size of the page to be returned
        :type size: int
        :param sort: Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.
        :type sort: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_responses_using_form_identifier_serialize(
            form_identifier=form_identifier,
            search=search,
            page=page,
            size=size,
            sort=sort,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponsesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_responses_using_form_identifier_with_http_info(
        self,
        form_identifier: StrictStr,
        search: Optional[StrictStr] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Zero-based page index (0..N)")] = None,
        size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The size of the page to be returned")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormResponsesResponse]:
        """get_responses_using_form_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param search:
        :type search: str
        :param page: Zero-based page index (0..N)
        :type page: int
        :param size: The size of the page to be returned
        :type size: int
        :param sort: Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.
        :type sort: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_responses_using_form_identifier_serialize(
            form_identifier=form_identifier,
            search=search,
            page=page,
            size=size,
            sort=sort,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponsesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_responses_using_form_identifier_without_preload_content(
        self,
        form_identifier: StrictStr,
        search: Optional[StrictStr] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Zero-based page index (0..N)")] = None,
        size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The size of the page to be returned")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_responses_using_form_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param search:
        :type search: str
        :param page: Zero-based page index (0..N)
        :type page: int
        :param size: The size of the page to be returned
        :type size: int
        :param sort: Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.
        :type sort: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_responses_using_form_identifier_serialize(
            form_identifier=form_identifier,
            search=search,
            page=page,
            size=size,
            sort=sort,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormResponsesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_responses_using_form_identifier_serialize(
        self,
        form_identifier,
        search,
        page,
        size,
        sort,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sort': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_identifier is not None:
            _path_params['formIdentifier'] = form_identifier
        # process the query parameters
        if search is not None:
            
            _query_params.append(('search', search))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms/identifier={formIdentifier}/responses',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_forms(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FormsResponse:
        """list_forms


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_forms_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_forms_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FormsResponse]:
        """list_forms


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_forms_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_forms_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """list_forms


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_forms_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FormsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_forms_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/forms',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_form_response(
        self,
        form_id: StrictStr,
        form_response_id: StrictStr,
        update_form_response_request: UpdateFormResponseRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """update_form_response


        :param form_id: (required)
        :type form_id: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param update_form_response_request: (required)
        :type update_form_response_request: UpdateFormResponseRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_response_serialize(
            form_id=form_id,
            form_response_id=form_response_id,
            update_form_response_request=update_form_response_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_form_response_with_http_info(
        self,
        form_id: StrictStr,
        form_response_id: StrictStr,
        update_form_response_request: UpdateFormResponseRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """update_form_response


        :param form_id: (required)
        :type form_id: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param update_form_response_request: (required)
        :type update_form_response_request: UpdateFormResponseRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_response_serialize(
            form_id=form_id,
            form_response_id=form_response_id,
            update_form_response_request=update_form_response_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_form_response_without_preload_content(
        self,
        form_id: StrictStr,
        form_response_id: StrictStr,
        update_form_response_request: UpdateFormResponseRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """update_form_response


        :param form_id: (required)
        :type form_id: str
        :param form_response_id: (required)
        :type form_response_id: str
        :param update_form_response_request: (required)
        :type update_form_response_request: UpdateFormResponseRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_response_serialize(
            form_id=form_id,
            form_response_id=form_response_id,
            update_form_response_request=update_form_response_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_form_response_serialize(
        self,
        form_id,
        form_response_id,
        update_form_response_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_id is not None:
            _path_params['formId'] = form_id
        if form_response_id is not None:
            _path_params['formResponseId'] = form_response_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_form_response_request is not None:
            _body_params = update_form_response_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/forms/{formId}/responses/{formResponseId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_form_response_with_identifier(
        self,
        form_identifier: Any,
        form_response_id: StrictStr,
        update_form_response_request: UpdateFormResponseRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """update_form_response_with_identifier


        :param form_identifier: (required)
        :type form_identifier: object
        :param form_response_id: (required)
        :type form_response_id: str
        :param update_form_response_request: (required)
        :type update_form_response_request: UpdateFormResponseRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_response_with_identifier_serialize(
            form_identifier=form_identifier,
            form_response_id=form_response_id,
            update_form_response_request=update_form_response_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_form_response_with_identifier_with_http_info(
        self,
        form_identifier: Any,
        form_response_id: StrictStr,
        update_form_response_request: UpdateFormResponseRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """update_form_response_with_identifier


        :param form_identifier: (required)
        :type form_identifier: object
        :param form_response_id: (required)
        :type form_response_id: str
        :param update_form_response_request: (required)
        :type update_form_response_request: UpdateFormResponseRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_response_with_identifier_serialize(
            form_identifier=form_identifier,
            form_response_id=form_response_id,
            update_form_response_request=update_form_response_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_form_response_with_identifier_without_preload_content(
        self,
        form_identifier: Any,
        form_response_id: StrictStr,
        update_form_response_request: UpdateFormResponseRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """update_form_response_with_identifier


        :param form_identifier: (required)
        :type form_identifier: object
        :param form_response_id: (required)
        :type form_response_id: str
        :param update_form_response_request: (required)
        :type update_form_response_request: UpdateFormResponseRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_response_with_identifier_serialize(
            form_identifier=form_identifier,
            form_response_id=form_response_id,
            update_form_response_request=update_form_response_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_form_response_with_identifier_serialize(
        self,
        form_identifier,
        form_response_id,
        update_form_response_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_identifier is not None:
            _path_params['formIdentifier'] = form_identifier
        if form_response_id is not None:
            _path_params['formResponseId'] = form_response_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_form_response_request is not None:
            _body_params = update_form_response_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/forms/identifier={formIdentifier}/responses/{formResponseId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_form_using_id(
        self,
        form_id: StrictStr,
        update_form_request: UpdateFormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """update_form_using_id


        :param form_id: (required)
        :type form_id: str
        :param update_form_request: (required)
        :type update_form_request: UpdateFormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_using_id_serialize(
            form_id=form_id,
            update_form_request=update_form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_form_using_id_with_http_info(
        self,
        form_id: StrictStr,
        update_form_request: UpdateFormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """update_form_using_id


        :param form_id: (required)
        :type form_id: str
        :param update_form_request: (required)
        :type update_form_request: UpdateFormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_using_id_serialize(
            form_id=form_id,
            update_form_request=update_form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_form_using_id_without_preload_content(
        self,
        form_id: StrictStr,
        update_form_request: UpdateFormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """update_form_using_id


        :param form_id: (required)
        :type form_id: str
        :param update_form_request: (required)
        :type update_form_request: UpdateFormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_using_id_serialize(
            form_id=form_id,
            update_form_request=update_form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_form_using_id_serialize(
        self,
        form_id,
        update_form_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_id is not None:
            _path_params['formId'] = form_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_form_request is not None:
            _body_params = update_form_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/forms/{formId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_form_using_identifier(
        self,
        form_identifier: StrictStr,
        update_form_request: UpdateFormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """update_form_using_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param update_form_request: (required)
        :type update_form_request: UpdateFormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_using_identifier_serialize(
            form_identifier=form_identifier,
            update_form_request=update_form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_form_using_identifier_with_http_info(
        self,
        form_identifier: StrictStr,
        update_form_request: UpdateFormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """update_form_using_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param update_form_request: (required)
        :type update_form_request: UpdateFormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_using_identifier_serialize(
            form_identifier=form_identifier,
            update_form_request=update_form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_form_using_identifier_without_preload_content(
        self,
        form_identifier: StrictStr,
        update_form_request: UpdateFormRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """update_form_using_identifier


        :param form_identifier: (required)
        :type form_identifier: str
        :param update_form_request: (required)
        :type update_form_request: UpdateFormRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_form_using_identifier_serialize(
            form_identifier=form_identifier,
            update_form_request=update_form_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_form_using_identifier_serialize(
        self,
        form_identifier,
        update_form_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if form_identifier is not None:
            _path_params['formIdentifier'] = form_identifier
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_form_request is not None:
            _body_params = update_form_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'apiKeyAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/forms/identifier={formIdentifier}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.15"

# Define package exports
__all__ = [
    "ApiKeysApi",
    "AppsApi",
    "AssetTypesApi",
    "AssetsApi",
    "AttachmentsApi",
    "BillingApi",
    "CollaboratorsApi",
    "ControlRoomsApi",
    "CycleTypesApi",
    "CyclesApi",
    "ErrorsApi",
    "EventTypesApi",
    "EventsApi",
    "FormApi",
    "FormsApi",
    "OrganizationApi",
    "PlaceTypesApi",
    "PlacesApi",
    "RuleTypesApi",
    "RulesApi",
    "TaskTypesApi",
    "TasksApi",
    "UsersApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Action",
    "AggregatedResponse",
    "AggregationParameterRequest",
    "ApiKeyResponse",
    "ApiKeysResponse",
    "AssetAttachments",
    "AssetAttachmentsResponse",
    "AssetCount",
    "AssetLocationResponse",
    "AssetMapViewResponse",
    "AssetMetricResponse",
    "AssetRequest",
    "AssetResponse",
    "AssetSearchRequest",
    "AssetSnapshotResponse",
    "AssetTableViewResponse",
    "AssetTypeRequest",
    "AssetTypeResponse",
    "AssetTypes",
    "Assets",
    "AssetsAggregationResponse",
    "AttachmentResource",
    "AttachmentResponse",
    "AttachmentUpdate",
    "AttachmentsRequest",
    "AttachmentsRequestAttachmentsInner",
    "AuthorizePaymentMethodRequest",
    "BillingPlanResponse",
    "ChangeLog",
    "ClearControlRoomEventsRequest",
    "CollaboratorResponse",
    "CollaboratorsResponse",
    "ControlRoom",
    "ControlRoomAssetSettingsResponse",
    "ControlRoomCollaboratorRequest",
    "ControlRoomCollaboratorResponse",
    "ControlRoomCollaboratorsRequest",
    "ControlRoomConfigResponse",
    "ControlRoomEventChangeResponse",
    "ControlRoomEventChangesResponse",
    "ControlRoomEventResponse",
    "ControlRoomEventSearchRequest",
    "ControlRoomEventsResponse",
    "ControlRoomEventsSummaryResponse",
    "ControlRoomResponse",
    "ControlRoomRulesResponse",
    "ControlRoomTaskSearchRequest",
    "ControlRoomTasksResponse",
    "ControlRoomsResponse",
    "CopyAttachmentAction",
    "CreateAttachmentAction",
    "CreateControlRoomRequest",
    "CreateEventResponse",
    "CreateUserRequest",
    "Crs",
    "CycleAggregationParameterRequest",
    "CycleRequest",
    "CycleResponse",
    "CycleSearchRequest",
    "CycleSummaries",
    "CycleSummaryRequest",
    "CycleSummaryResponse",
    "CycleTypeDisplaySettingsDto",
    "CycleTypeEndpointsDto",
    "CycleTypeMetricsDto",
    "CycleTypeRequest",
    "CycleTypeResponse",
    "CycleTypes",
    "Cycles",
    "DateGrouping",
    "DateRange",
    "DeleteTaskRequest",
    "EmailChannel",
    "EntityResponse",
    "EventCreatedOptions",
    "EventDisplay",
    "EventPlace",
    "EventRequest",
    "EventResponse",
    "EventSearchRequest",
    "EventTypeCount",
    "EventTypeRequest",
    "EventTypeResponse",
    "EventTypes",
    "EventWarning",
    "Events",
    "ExcessChargePolicy",
    "ExecuteAssetsAggregationRequest",
    "ExecutePeriodAggregationRequest",
    "Execution",
    "Filter",
    "FormAction",
    "FormRequest",
    "FormResourceHeaderRequest",
    "FormResourceHeaderResponse",
    "FormResourceRequest",
    "FormResourceResponse",
    "FormResponse",
    "FormResponseRequest",
    "FormResponseResponse",
    "FormResponsesResponse",
    "FormShortResponse",
    "FormsResponse",
    "Importance",
    "ImportanceCount",
    "InstallAppRequest",
    "InstalledAppResponse",
    "InstalledAppsResponse",
    "InviteUserRequest",
    "InviteUsersRequest",
    "InvoiceResponse",
    "InvoicesResponse",
    "Link",
    "LinkedAssetResponse",
    "LinkedPlaceResponse",
    "LngLatAlt",
    "LocationHistory",
    "MailingListSubscriptionRequest",
    "MailingListSubscriptionResponse",
    "MapRuleResponse",
    "MapTooltipResponse",
    "MapUpdateResponse",
    "MetricHistory",
    "ModelField",
    "ModelProperty",
    "NotificationActionConfig",
    "NotificationActionConfigChannelsInner",
    "NotificationChannel",
    "NotificationRuleAction",
    "OrganizationResponse",
    "Pageable",
    "PaymentMethodResponse",
    "PaymentMethodsResponse",
    "PeriodAggregatedResponse",
    "PeriodAggregationResponse",
    "PlaceEnteredExitedOptions",
    "PlaceRequest",
    "PlaceResponse",
    "PlaceTypeRequest",
    "PlaceTypeResponse",
    "PlaceTypes",
    "Places",
    "PlanConstraint",
    "Polygon",
    "PushChannel",
    "QuickFilter",
    "QuickFilterEntry",
    "Range",
    "ReportUrlResponse",
    "RuleActionObjectObject",
    "RuleRequest",
    "RuleResponse",
    "RuleTypeRequest",
    "RuleTypeResponse",
    "RuleTypes",
    "RulesResponse",
    "RulesSearchRequest",
    "SearchAssetAttributeRequest",
    "SearchAssetAttributeResponse",
    "SmsChannel",
    "TaskAssetResponse",
    "TaskCreatedOptions",
    "TaskEventResponse",
    "TaskRequest",
    "TaskResponse",
    "TaskSearchRequest",
    "TaskTypeRequest",
    "TaskTypeResponse",
    "TaskTypes",
    "Tasks",
    "Tooltip",
    "TriggeredBy",
    "UpdateAssetMapViewRequest",
    "UpdateAssetRequest",
    "UpdateAssetTableViewRequest",
    "UpdateAssetTypeRequest",
    "UpdateControlRoomAssetSettingsRequest",
    "UpdateControlRoomCollaboratorRequest",
    "UpdateControlRoomConfigRequest",
    "UpdateControlRoomRequest",
    "UpdateCycleRequest",
    "UpdateCycleTypeRequest",
    "UpdateEventRequest",
    "UpdateEventTypeRequest",
    "UpdateFormRequest",
    "UpdateFormResponseRequest",
    "UpdateInstalledAppRequest",
    "UpdateOrganizationRequest",
    "UpdatePlaceRequest",
    "UpdatePlaceTypeRequest",
    "UpdateRuleRequest",
    "UpdateRuleTypeRequest",
    "UpdateRuleTypeRequestOptions",
    "UpdateTaskRequest",
    "UpdateTaskTypeRequest",
    "UpdateUserDeviceRequest",
    "UpdateUserPreferencesRequest",
    "UpdateUserRequest",
    "UploadSignatureResponse",
    "UserDetailsResponse",
    "UserDeviceResponse",
    "UserDevicesResponse",
    "UserPreferenceResponse",
    "UserPreferencesResponse",
    "UserResponse",
    "UsersResponse",
    "Widget",
]

# import apis into sdk package
from skyledge_sdk.api.api_keys_api import ApiKeysApi as ApiKeysApi
from skyledge_sdk.api.apps_api import AppsApi as AppsApi
from skyledge_sdk.api.asset_types_api import AssetTypesApi as AssetTypesApi
from skyledge_sdk.api.assets_api import AssetsApi as AssetsApi
from skyledge_sdk.api.attachments_api import AttachmentsApi as AttachmentsApi
from skyledge_sdk.api.billing_api import BillingApi as BillingApi
from skyledge_sdk.api.collaborators_api import CollaboratorsApi as CollaboratorsApi
from skyledge_sdk.api.control_rooms_api import ControlRoomsApi as ControlRoomsApi
from skyledge_sdk.api.cycle_types_api import CycleTypesApi as CycleTypesApi
from skyledge_sdk.api.cycles_api import CyclesApi as CyclesApi
from skyledge_sdk.api.errors_api import ErrorsApi as ErrorsApi
from skyledge_sdk.api.event_types_api import EventTypesApi as EventTypesApi
from skyledge_sdk.api.events_api import EventsApi as EventsApi
from skyledge_sdk.api.form_api import FormApi as FormApi
from skyledge_sdk.api.forms_api import FormsApi as FormsApi
from skyledge_sdk.api.organization_api import OrganizationApi as OrganizationApi
from skyledge_sdk.api.place_types_api import PlaceTypesApi as PlaceTypesApi
from skyledge_sdk.api.places_api import PlacesApi as PlacesApi
from skyledge_sdk.api.rule_types_api import RuleTypesApi as RuleTypesApi
from skyledge_sdk.api.rules_api import RulesApi as RulesApi
from skyledge_sdk.api.task_types_api import TaskTypesApi as TaskTypesApi
from skyledge_sdk.api.tasks_api import TasksApi as TasksApi
from skyledge_sdk.api.users_api import UsersApi as UsersApi

# import ApiClient
from skyledge_sdk.api_response import ApiResponse as ApiResponse
from skyledge_sdk.api_client import ApiClient as ApiClient
from skyledge_sdk.configuration import Configuration as Configuration
from skyledge_sdk.exceptions import OpenApiException as OpenApiException
from skyledge_sdk.exceptions import ApiTypeError as ApiTypeError
from skyledge_sdk.exceptions import ApiValueError as ApiValueError
from skyledge_sdk.exceptions import ApiKeyError as ApiKeyError
from skyledge_sdk.exceptions import ApiAttributeError as ApiAttributeError
from skyledge_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from skyledge_sdk.models.action import Action as Action
from skyledge_sdk.models.aggregated_response import AggregatedResponse as AggregatedResponse
from skyledge_sdk.models.aggregation_parameter_request import AggregationParameterRequest as AggregationParameterRequest
from skyledge_sdk.models.api_key_response import ApiKeyResponse as ApiKeyResponse
from skyledge_sdk.models.api_keys_response import ApiKeysResponse as ApiKeysResponse
from skyledge_sdk.models.asset_attachments import AssetAttachments as AssetAttachments
from skyledge_sdk.models.asset_attachments_response import AssetAttachmentsResponse as AssetAttachmentsResponse
from skyledge_sdk.models.asset_count import AssetCount as AssetCount
from skyledge_sdk.models.asset_location_response import AssetLocationResponse as AssetLocationResponse
from skyledge_sdk.models.asset_map_view_response import AssetMapViewResponse as AssetMapViewResponse
from skyledge_sdk.models.asset_metric_response import AssetMetricResponse as AssetMetricResponse
from skyledge_sdk.models.asset_request import AssetRequest as AssetRequest
from skyledge_sdk.models.asset_response import AssetResponse as AssetResponse
from skyledge_sdk.models.asset_search_request import AssetSearchRequest as AssetSearchRequest
from skyledge_sdk.models.asset_snapshot_response import AssetSnapshotResponse as AssetSnapshotResponse
from skyledge_sdk.models.asset_table_view_response import AssetTableViewResponse as AssetTableViewResponse
from skyledge_sdk.models.asset_type_request import AssetTypeRequest as AssetTypeRequest
from skyledge_sdk.models.asset_type_response import AssetTypeResponse as AssetTypeResponse
from skyledge_sdk.models.asset_types import AssetTypes as AssetTypes
from skyledge_sdk.models.assets import Assets as Assets
from skyledge_sdk.models.assets_aggregation_response import AssetsAggregationResponse as AssetsAggregationResponse
from skyledge_sdk.models.attachment_resource import AttachmentResource as AttachmentResource
from skyledge_sdk.models.attachment_response import AttachmentResponse as AttachmentResponse
from skyledge_sdk.models.attachment_update import AttachmentUpdate as AttachmentUpdate
from skyledge_sdk.models.attachments_request import AttachmentsRequest as AttachmentsRequest
from skyledge_sdk.models.attachments_request_attachments_inner import AttachmentsRequestAttachmentsInner as AttachmentsRequestAttachmentsInner
from skyledge_sdk.models.authorize_payment_method_request import AuthorizePaymentMethodRequest as AuthorizePaymentMethodRequest
from skyledge_sdk.models.billing_plan_response import BillingPlanResponse as BillingPlanResponse
from skyledge_sdk.models.change_log import ChangeLog as ChangeLog
from skyledge_sdk.models.clear_control_room_events_request import ClearControlRoomEventsRequest as ClearControlRoomEventsRequest
from skyledge_sdk.models.collaborator_response import CollaboratorResponse as CollaboratorResponse
from skyledge_sdk.models.collaborators_response import CollaboratorsResponse as CollaboratorsResponse
from skyledge_sdk.models.control_room import ControlRoom as ControlRoom
from skyledge_sdk.models.control_room_asset_settings_response import ControlRoomAssetSettingsResponse as ControlRoomAssetSettingsResponse
from skyledge_sdk.models.control_room_collaborator_request import ControlRoomCollaboratorRequest as ControlRoomCollaboratorRequest
from skyledge_sdk.models.control_room_collaborator_response import ControlRoomCollaboratorResponse as ControlRoomCollaboratorResponse
from skyledge_sdk.models.control_room_collaborators_request import ControlRoomCollaboratorsRequest as ControlRoomCollaboratorsRequest
from skyledge_sdk.models.control_room_config_response import ControlRoomConfigResponse as ControlRoomConfigResponse
from skyledge_sdk.models.control_room_event_change_response import ControlRoomEventChangeResponse as ControlRoomEventChangeResponse
from skyledge_sdk.models.control_room_event_changes_response import ControlRoomEventChangesResponse as ControlRoomEventChangesResponse
from skyledge_sdk.models.control_room_event_response import ControlRoomEventResponse as ControlRoomEventResponse
from skyledge_sdk.models.control_room_event_search_request import ControlRoomEventSearchRequest as ControlRoomEventSearchRequest
from skyledge_sdk.models.control_room_events_response import ControlRoomEventsResponse as ControlRoomEventsResponse
from skyledge_sdk.models.control_room_events_summary_response import ControlRoomEventsSummaryResponse as ControlRoomEventsSummaryResponse
from skyledge_sdk.models.control_room_response import ControlRoomResponse as ControlRoomResponse
from skyledge_sdk.models.control_room_rules_response import ControlRoomRulesResponse as ControlRoomRulesResponse
from skyledge_sdk.models.control_room_task_search_request import ControlRoomTaskSearchRequest as ControlRoomTaskSearchRequest
from skyledge_sdk.models.control_room_tasks_response import ControlRoomTasksResponse as ControlRoomTasksResponse
from skyledge_sdk.models.control_rooms_response import ControlRoomsResponse as ControlRoomsResponse
from skyledge_sdk.models.copy_attachment_action import CopyAttachmentAction as CopyAttachmentAction
from skyledge_sdk.models.create_attachment_action import CreateAttachmentAction as CreateAttachmentAction
from skyledge_sdk.models.create_control_room_request import CreateControlRoomRequest as CreateControlRoomRequest
from skyledge_sdk.models.create_event_response import CreateEventResponse as CreateEventResponse
from skyledge_sdk.models.create_user_request import CreateUserRequest as CreateUserRequest
from skyledge_sdk.models.crs import Crs as Crs
from skyledge_sdk.models.cycle_aggregation_parameter_request import CycleAggregationParameterRequest as CycleAggregationParameterRequest
from skyledge_sdk.models.cycle_request import CycleRequest as CycleRequest
from skyledge_sdk.models.cycle_response import CycleResponse as CycleResponse
from skyledge_sdk.models.cycle_search_request import CycleSearchRequest as CycleSearchRequest
from skyledge_sdk.models.cycle_summaries import CycleSummaries as CycleSummaries
from skyledge_sdk.models.cycle_summary_request import CycleSummaryRequest as CycleSummaryRequest
from skyledge_sdk.models.cycle_summary_response import CycleSummaryResponse as CycleSummaryResponse
from skyledge_sdk.models.cycle_type_display_settings_dto import CycleTypeDisplaySettingsDto as CycleTypeDisplaySettingsDto
from skyledge_sdk.models.cycle_type_endpoints_dto import CycleTypeEndpointsDto as CycleTypeEndpointsDto
from skyledge_sdk.models.cycle_type_metrics_dto import CycleTypeMetricsDto as CycleTypeMetricsDto
from skyledge_sdk.models.cycle_type_request import CycleTypeRequest as CycleTypeRequest
from skyledge_sdk.models.cycle_type_response import CycleTypeResponse as CycleTypeResponse
from skyledge_sdk.models.cycle_types import CycleTypes as CycleTypes
from skyledge_sdk.models.cycles import Cycles as Cycles
from skyledge_sdk.models.date_grouping import DateGrouping as DateGrouping
from skyledge_sdk.models.date_range import DateRange as DateRange
from skyledge_sdk.models.delete_task_request import DeleteTaskRequest as DeleteTaskRequest
from skyledge_sdk.models.email_channel import EmailChannel as EmailChannel
from skyledge_sdk.models.entity_response import EntityResponse as EntityResponse
from skyledge_sdk.models.event_created_options import EventCreatedOptions as EventCreatedOptions
from skyledge_sdk.models.event_display import EventDisplay as EventDisplay
from skyledge_sdk.models.event_place import EventPlace as EventPlace
from skyledge_sdk.models.event_request import EventRequest as EventRequest
from skyledge_sdk.models.event_response import EventResponse as EventResponse
from skyledge_sdk.models.event_search_request import EventSearchRequest as EventSearchRequest
from skyledge_sdk.models.event_type_count import EventTypeCount as EventTypeCount
from skyledge_sdk.models.event_type_request import EventTypeRequest as EventTypeRequest
from skyledge_sdk.models.event_type_response import EventTypeResponse as EventTypeResponse
from skyledge_sdk.models.event_types import EventTypes as EventTypes
from skyledge_sdk.models.event_warning import EventWarning as EventWarning
from skyledge_sdk.models.events import Events as Events
from skyledge_sdk.models.excess_charge_policy import ExcessChargePolicy as ExcessChargePolicy
from skyledge_sdk.models.execute_assets_aggregation_request import ExecuteAssetsAggregationRequest as ExecuteAssetsAggregationRequest
from skyledge_sdk.models.execute_period_aggregation_request import ExecutePeriodAggregationRequest as ExecutePeriodAggregationRequest
from skyledge_sdk.models.execution import Execution as Execution
from skyledge_sdk.models.filter import Filter as Filter
from skyledge_sdk.models.form_action import FormAction as FormAction
from skyledge_sdk.models.form_request import FormRequest as FormRequest
from skyledge_sdk.models.form_resource_header_request import FormResourceHeaderRequest as FormResourceHeaderRequest
from skyledge_sdk.models.form_resource_header_response import FormResourceHeaderResponse as FormResourceHeaderResponse
from skyledge_sdk.models.form_resource_request import FormResourceRequest as FormResourceRequest
from skyledge_sdk.models.form_resource_response import FormResourceResponse as FormResourceResponse
from skyledge_sdk.models.form_response import FormResponse as FormResponse
from skyledge_sdk.models.form_response_request import FormResponseRequest as FormResponseRequest
from skyledge_sdk.models.form_response_response import FormResponseResponse as FormResponseResponse
from skyledge_sdk.models.form_responses_response import FormResponsesResponse as FormResponsesResponse
from skyledge_sdk.models.form_short_response import FormShortResponse as FormShortResponse
from skyledge_sdk.models.forms_response import FormsResponse as FormsResponse
from skyledge_sdk.models.importance import Importance as Importance
from skyledge_sdk.models.importance_count import ImportanceCount as ImportanceCount
from skyledge_sdk.models.install_app_request import InstallAppRequest as InstallAppRequest
from skyledge_sdk.models.installed_app_response import InstalledAppResponse as InstalledAppResponse
from skyledge_sdk.models.installed_apps_response import InstalledAppsResponse as InstalledAppsResponse
from skyledge_sdk.models.invite_user_request import InviteUserRequest as InviteUserRequest
from skyledge_sdk.models.invite_users_request import InviteUsersRequest as InviteUsersRequest
from skyledge_sdk.models.invoice_response import InvoiceResponse as InvoiceResponse
from skyledge_sdk.models.invoices_response import InvoicesResponse as InvoicesResponse
from skyledge_sdk.models.link import Link as Link
from skyledge_sdk.models.linked_asset_response import LinkedAssetResponse as LinkedAssetResponse
from skyledge_sdk.models.linked_place_response import LinkedPlaceResponse as LinkedPlaceResponse
from skyledge_sdk.models.lng_lat_alt import LngLatAlt as LngLatAlt
from skyledge_sdk.models.location_history import LocationHistory as LocationHistory
from skyledge_sdk.models.mailing_list_subscription_request import MailingListSubscriptionRequest as MailingListSubscriptionRequest
from skyledge_sdk.models.mailing_list_subscription_response import MailingListSubscriptionResponse as MailingListSubscriptionResponse
from skyledge_sdk.models.map_rule_response import MapRuleResponse as MapRuleResponse
from skyledge_sdk.models.map_tooltip_response import MapTooltipResponse as MapTooltipResponse
from skyledge_sdk.models.map_update_response import MapUpdateResponse as MapUpdateResponse
from skyledge_sdk.models.metric_history import MetricHistory as MetricHistory
from skyledge_sdk.models.model_field import ModelField as ModelField
from skyledge_sdk.models.model_property import ModelProperty as ModelProperty
from skyledge_sdk.models.notification_action_config import NotificationActionConfig as NotificationActionConfig
from skyledge_sdk.models.notification_action_config_channels_inner import NotificationActionConfigChannelsInner as NotificationActionConfigChannelsInner
from skyledge_sdk.models.notification_channel import NotificationChannel as NotificationChannel
from skyledge_sdk.models.notification_rule_action import NotificationRuleAction as NotificationRuleAction
from skyledge_sdk.models.organization_response import OrganizationResponse as OrganizationResponse
from skyledge_sdk.models.pageable import Pageable as Pageable
from skyledge_sdk.models.payment_method_response import PaymentMethodResponse as PaymentMethodResponse
from skyledge_sdk.models.payment_methods_response import PaymentMethodsResponse as PaymentMethodsResponse
from skyledge_sdk.models.period_aggregated_response import PeriodAggregatedResponse as PeriodAggregatedResponse
from skyledge_sdk.models.period_aggregation_response import PeriodAggregationResponse as PeriodAggregationResponse
from skyledge_sdk.models.place_entered_exited_options import PlaceEnteredExitedOptions as PlaceEnteredExitedOptions
from skyledge_sdk.models.place_request import PlaceRequest as PlaceRequest
from skyledge_sdk.models.place_response import PlaceResponse as PlaceResponse
from skyledge_sdk.models.place_type_request import PlaceTypeRequest as PlaceTypeRequest
from skyledge_sdk.models.place_type_response import PlaceTypeResponse as PlaceTypeResponse
from skyledge_sdk.models.place_types import PlaceTypes as PlaceTypes
from skyledge_sdk.models.places import Places as Places
from skyledge_sdk.models.plan_constraint import PlanConstraint as PlanConstraint
from skyledge_sdk.models.polygon import Polygon as Polygon
from skyledge_sdk.models.push_channel import PushChannel as PushChannel
from skyledge_sdk.models.quick_filter import QuickFilter as QuickFilter
from skyledge_sdk.models.quick_filter_entry import QuickFilterEntry as QuickFilterEntry
from skyledge_sdk.models.range import Range as Range
from skyledge_sdk.models.report_url_response import ReportUrlResponse as ReportUrlResponse
from skyledge_sdk.models.rule_action_object_object import RuleActionObjectObject as RuleActionObjectObject
from skyledge_sdk.models.rule_request import RuleRequest as RuleRequest
from skyledge_sdk.models.rule_response import RuleResponse as RuleResponse
from skyledge_sdk.models.rule_type_request import RuleTypeRequest as RuleTypeRequest
from skyledge_sdk.models.rule_type_response import RuleTypeResponse as RuleTypeResponse
from skyledge_sdk.models.rule_types import RuleTypes as RuleTypes
from skyledge_sdk.models.rules_response import RulesResponse as RulesResponse
from skyledge_sdk.models.rules_search_request import RulesSearchRequest as RulesSearchRequest
from skyledge_sdk.models.search_asset_attribute_request import SearchAssetAttributeRequest as SearchAssetAttributeRequest
from skyledge_sdk.models.search_asset_attribute_response import SearchAssetAttributeResponse as SearchAssetAttributeResponse
from skyledge_sdk.models.sms_channel import SmsChannel as SmsChannel
from skyledge_sdk.models.task_asset_response import TaskAssetResponse as TaskAssetResponse
from skyledge_sdk.models.task_created_options import TaskCreatedOptions as TaskCreatedOptions
from skyledge_sdk.models.task_event_response import TaskEventResponse as TaskEventResponse
from skyledge_sdk.models.task_request import TaskRequest as TaskRequest
from skyledge_sdk.models.task_response import TaskResponse as TaskResponse
from skyledge_sdk.models.task_search_request import TaskSearchRequest as TaskSearchRequest
from skyledge_sdk.models.task_type_request import TaskTypeRequest as TaskTypeRequest
from skyledge_sdk.models.task_type_response import TaskTypeResponse as TaskTypeResponse
from skyledge_sdk.models.task_types import TaskTypes as TaskTypes
from skyledge_sdk.models.tasks import Tasks as Tasks
from skyledge_sdk.models.tooltip import Tooltip as Tooltip
from skyledge_sdk.models.triggered_by import TriggeredBy as TriggeredBy
from skyledge_sdk.models.update_asset_map_view_request import UpdateAssetMapViewRequest as UpdateAssetMapViewRequest
from skyledge_sdk.models.update_asset_request import UpdateAssetRequest as UpdateAssetRequest
from skyledge_sdk.models.update_asset_table_view_request import UpdateAssetTableViewRequest as UpdateAssetTableViewRequest
from skyledge_sdk.models.update_asset_type_request import UpdateAssetTypeRequest as UpdateAssetTypeRequest
from skyledge_sdk.models.update_control_room_asset_settings_request import UpdateControlRoomAssetSettingsRequest as UpdateControlRoomAssetSettingsRequest
from skyledge_sdk.models.update_control_room_collaborator_request import UpdateControlRoomCollaboratorRequest as UpdateControlRoomCollaboratorRequest
from skyledge_sdk.models.update_control_room_config_request import UpdateControlRoomConfigRequest as UpdateControlRoomConfigRequest
from skyledge_sdk.models.update_control_room_request import UpdateControlRoomRequest as UpdateControlRoomRequest
from skyledge_sdk.models.update_cycle_request import UpdateCycleRequest as UpdateCycleRequest
from skyledge_sdk.models.update_cycle_type_request import UpdateCycleTypeRequest as UpdateCycleTypeRequest
from skyledge_sdk.models.update_event_request import UpdateEventRequest as UpdateEventRequest
from skyledge_sdk.models.update_event_type_request import UpdateEventTypeRequest as UpdateEventTypeRequest
from skyledge_sdk.models.update_form_request import UpdateFormRequest as UpdateFormRequest
from skyledge_sdk.models.update_form_response_request import UpdateFormResponseRequest as UpdateFormResponseRequest
from skyledge_sdk.models.update_installed_app_request import UpdateInstalledAppRequest as UpdateInstalledAppRequest
from skyledge_sdk.models.update_organization_request import UpdateOrganizationRequest as UpdateOrganizationRequest
from skyledge_sdk.models.update_place_request import UpdatePlaceRequest as UpdatePlaceRequest
from skyledge_sdk.models.update_place_type_request import UpdatePlaceTypeRequest as UpdatePlaceTypeRequest
from skyledge_sdk.models.update_rule_request import UpdateRuleRequest as UpdateRuleRequest
from skyledge_sdk.models.update_rule_type_request import UpdateRuleTypeRequest as UpdateRuleTypeRequest
from skyledge_sdk.models.update_rule_type_request_options import UpdateRuleTypeRequestOptions as UpdateRuleTypeRequestOptions
from skyledge_sdk.models.update_task_request import UpdateTaskRequest as UpdateTaskRequest
from skyledge_sdk.models.update_task_type_request import UpdateTaskTypeRequest as UpdateTaskTypeRequest
from skyledge_sdk.models.update_user_device_request import UpdateUserDeviceRequest as UpdateUserDeviceRequest
from skyledge_sdk.models.update_user_preferences_request import UpdateUserPreferencesRequest as UpdateUserPreferencesRequest
from skyledge_sdk.models.update_user_request import UpdateUserRequest as UpdateUserRequest
from skyledge_sdk.models.upload_signature_response import UploadSignatureResponse as UploadSignatureResponse
from skyledge_sdk.models.user_details_response import UserDetailsResponse as UserDetailsResponse
from skyledge_sdk.models.user_device_response import UserDeviceResponse as UserDeviceResponse
from skyledge_sdk.models.user_devices_response import UserDevicesResponse as UserDevicesResponse
from skyledge_sdk.models.user_preference_response import UserPreferenceResponse as UserPreferenceResponse
from skyledge_sdk.models.user_preferences_response import UserPreferencesResponse as UserPreferencesResponse
from skyledge_sdk.models.user_response import UserResponse as UserResponse
from skyledge_sdk.models.users_response import UsersResponse as UsersResponse
from skyledge_sdk.models.widget import Widget as Widget



# coding: utf-8

"""
    Skyledge API

    Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

    The version of the OpenAPI document: 1.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from skyledge_sdk.api.assets_api import AssetsApi


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AssetsApi()

    def tearDown(self) -> None:
        pass

    def test_create_asset(self) -> None:
        """Test case for create_asset

        """
        pass

    def test_create_asset_by_identifier(self) -> None:
        """Test case for create_asset_by_identifier

        """
        pass

    def test_execute_aggregation(self) -> None:
        """Test case for execute_aggregation

        """
        pass

    def test_execute_aggregation_by_id(self) -> None:
        """Test case for execute_aggregation_by_id

        """
        pass

    def test_execute_aggregation_by_identifier(self) -> None:
        """Test case for execute_aggregation_by_identifier

        """
        pass

    def test_get_asset_using_asset_id(self) -> None:
        """Test case for get_asset_using_asset_id

        """
        pass

    def test_get_asset_using_asset_identifier(self) -> None:
        """Test case for get_asset_using_asset_identifier

        """
        pass

    def test_list_asset_attribute_values_by_attribute_name(self) -> None:
        """Test case for list_asset_attribute_values_by_attribute_name

        """
        pass

    def test_list_asset_for_control_room(self) -> None:
        """Test case for list_asset_for_control_room

        """
        pass

    def test_list_assets(self) -> None:
        """Test case for list_assets

        """
        pass

    def test_retrieve_asset_snapshot(self) -> None:
        """Test case for retrieve_asset_snapshot

        """
        pass

    def test_retrieve_location_history_for_asset(self) -> None:
        """Test case for retrieve_location_history_for_asset

        """
        pass

    def test_retrieve_location_history_for_asset1(self) -> None:
        """Test case for retrieve_location_history_for_asset1

        """
        pass

    def test_retrieve_metrics_for_asset(self) -> None:
        """Test case for retrieve_metrics_for_asset

        """
        pass

    def test_retrieve_metrics_for_asset1(self) -> None:
        """Test case for retrieve_metrics_for_asset1

        """
        pass

    def test_search_assets(self) -> None:
        """Test case for search_assets

        """
        pass

    def test_update_asset_by_id(self) -> None:
        """Test case for update_asset_by_id

        """
        pass

    def test_update_asset_by_identifier(self) -> None:
        """Test case for update_asset_by_identifier

        """
        pass


if __name__ == '__main__':
    unittest.main()
